@@ -1,11 +1,11 @@
-#' Annotate Repository Sources
+#' Annotate repository sources
 #'
 #' @param string_og text string (script) with package load calls
 #'
 #' @return text string with package repository source annotations. Will make
 #'   note of packages not currently installed. Lines with existing comments or
 #'   annotations are ignored by the regular expression that matches package
-#'   names. Also ignores base packages.
+#'   names. Also ignores base packages. Local installs now annotated as such.
 #'
 #' @examples
 #' test_string <- c("library(boot)\nrequire(lattice)")
@@ -19,31 +19,52 @@ annotate_repo_source <- function(string_og) {
     return(string_og)
   }
   out_tb <- tibble::rowid_to_column(out_tb)
-  pck_descs <- purrr::map(out_tb$pkgname_clean, utils::packageDescription,
+  pck_descs <- suppressWarnings(purrr::map(out_tb$pkgname_clean,
+                          utils::packageDescription,
                           fields = c("Repository", "RemoteType", "biocViews")
-  )
+  ))
   pck_descs <- purrr::map(pck_descs, as.list)
-  pck_descs <- tidyr::unnest(tibble::enframe(purrr::map(pck_descs, purrr::flatten_chr)), cols = c(.data$value))
+  pck_descs <- tidyr::unnest(tibble::enframe(purrr::map(pck_descs, purrr::flatten_chr)), cols = c("value"))
   pck_descs <- dplyr::rename(pck_descs, rowid = 1, repo = 2)
   pck_descs <- dplyr::left_join(out_tb, pck_descs, by = "rowid")
   pck_descs <- dplyr::mutate(pck_descs, repo = ifelse(stringr::str_detect(.data$repo, ","), "Bioconductor", .data$repo))
   pck_descs <- dplyr::add_count(pck_descs, .data$package_name)
-  pck_descs <- stats::na.omit(dplyr::mutate(pck_descs, repo = dplyr::if_else(.data$n == 1, "none", .data$repo)))
+  pck_descs <- dplyr::mutate(pck_descs, repo = dplyr::if_else(.data$n == 1, "none", .data$repo))
+  pck_descs <-
+    suppressMessages(dplyr::ungroup(dplyr::summarize(
+      dplyr::group_by(pck_descs,call,.data$package_name,.data$pkgname_clean),repo=dplyr::last(stats::na.omit(.data$repo)))))
   pck_descs <- dplyr::mutate(pck_descs, user_repo = dplyr::case_when(
     .data$repo ==
       "CRAN" ~ "CRAN",
+    stringr::str_detect(.data$repo, "r-universe") ~ .data$repo,
     .data$repo == "Bioconductor" ~ "Bioconductor",
+    .data$repo == "RSPM" ~ "Posit RPSM",
     .data$repo == "none" ~ "not installed on this machine",
-    TRUE ~ repo_details(.data$package_name)
+    is.na(.data$repo) ~ "local install",
+    TRUE ~ repo_details(.data$pkgname_clean)
   ), annotation = dplyr::case_when(stringr::str_detect(
     user_repo,
-    "/"
+    "(?<!/)/(?!/)"
   ) ~ paste0("[", .data$repo, "::", user_repo, "]"), TRUE ~ user_repo))
-  pck_descs <- dplyr::mutate(pck_descs, version = pkg_version(.data$package_name))
+  pck_descs <- dplyr::mutate(pck_descs, version = pkg_version(.data$pkgname_clean))
+  # edge case with a single locally installed package
+  if (nrow(pck_descs) == 0) {
+    locannot <- paste(out_tb$call,"# local install")
+    return(
+      align_annotations(
+        stringi::stri_replace_all_fixed(
+          str = string_og, pattern = out_tb$call,
+          replacement = locannot, vectorize_all = FALSE
+        )
+      ))
+  }
 
   # build annotation
   if (all(!grepl("p_load", pck_descs$call))) { # no pacman calls
-    pck_descs$annotated <- paste0(pck_descs$call, " # ", pck_descs$annotation, " v", pck_descs$version)
+    pck_descs <-  dplyr::mutate(pck_descs,annotated=dplyr::case_when(
+      stringr::str_detect(annotation,"not installed")~paste0(call, " #", " ", annotation, " vNA"),
+      TRUE~ paste0(call, " #", " ", annotation, " v", version)
+    ))
     return(
       align_annotations(stringi::stri_replace_all_fixed(
         str = string_og, pattern = pck_descs$call,
@@ -53,7 +74,7 @@ annotate_repo_source <- function(string_og) {
   }
 
   if (all(grepl("p_load", pck_descs$call))) { # only pacman calls
-    pacld <- pck_descs[stringr::str_detect(out_tb$call, ".+load\\("), ]
+    pacld <- pck_descs[which(stringr::str_detect(out_tb$call, ".+load\\(")), ]
     pacld$pkgnamesep <- paste0(pacld$package_name, ",")
     pacld <- dplyr::mutate(dplyr::group_by(pacld, call), pkgnamesep = ifelse(dplyr::row_number() == dplyr::n(), gsub(",", "", .data$pkgnamesep), .data$pkgnamesep))
     pacld$annotatedpac <- paste0(pacld$pkgnamesep, " # ", pacld$annotation, " v", pacld$version)
@@ -69,7 +90,7 @@ annotate_repo_source <- function(string_og) {
   }
 
   if (any(grepl("p_load", pck_descs$call)) & any(grepl("libr|req", out_tb$call))) { # pacman and base calls
-    pacld <- pck_descs[stringr::str_detect(out_tb$call, ".+load\\("), ]
+    pacld <- pck_descs[which(stringr::str_detect(pck_descs$call, ".+load\\(")), ]
     pacld$pkgnamesep <- paste0(pacld$package_name, ",")
     pacld <- dplyr::mutate(dplyr::group_by(pacld, call), pkgnamesep = ifelse(dplyr::row_number() == dplyr::n(), gsub(",", "", .data$pkgnamesep), .data$pkgnamesep))
     pacld$annotatedpac <- paste0(pacld$pkgnamesep, " # ", pacld$annotation, " v", pacld$version)
@@ -81,12 +102,15 @@ annotate_repo_source <- function(string_og) {
       replacement = pacld$annotpac, vectorize_all = FALSE
     )
     pck_descs <- pck_descs[!stringr::str_detect(out_tb$call, ".+load\\("), ]
-    pck_descs$annotated <- paste0(pck_descs$call, " # ", pck_descs$annotation, " v", pck_descs$version)
+    pck_descs <-  dplyr::mutate(pck_descs,annotated=dplyr::case_when(
+      stringr::str_detect(annotation,"not installed")~paste0(call, " #", " ", annotation, " vNA"),
+      TRUE~ paste0(call, " #", " ", annotation, " v", version)
+    ))
 
     return(
       align_annotations(
         stringi::stri_replace_all_fixed(
-          str = string_og, pattern = out_tb$call,
+          str = string_og, pattern = pck_descs$call,
           replacement = pck_descs$annotated, vectorize_all = FALSE
         )
       )
