@@ -1,4 +1,4 @@
-#' Annotate Package Titles and Repository Sources
+#' Annotate package titles and repository sources
 #'
 #' @param string_og Text string (script) with package load calls.
 #'
@@ -31,7 +31,7 @@ annotate_repostitle <- function(string_og) {
     fields = c("Repository", "RemoteType", "biocViews")
   )
   pck_descs <- purrr::map(pck_descs, as.list)
-  pck_descs <- tidyr::unnest(tibble::enframe(purrr::map(pck_descs, purrr::flatten_chr)), cols = c(.data$value))
+  pck_descs <- tidyr::unnest(tibble::enframe(purrr::map(pck_descs, purrr::flatten_chr)), cols = c("value"))
   pck_descs <- dplyr::rename(pck_descs, rowid = 1, repo = 2)
   pck_descs <- dplyr::left_join(out_tb, pck_descs, by = "rowid")
   pck_descs <- dplyr::mutate(pck_descs, repo = ifelse(stringr::str_detect(.data$repo, ","), "Bioconductor", .data$repo))
@@ -41,44 +41,48 @@ annotate_repostitle <- function(string_og) {
     .data$repo ==
       "CRAN" ~ "CRAN",
     .data$repo == "Bioconductor" ~ "Bioconductor",
+    .data$repo == "RSPM" ~ "Posit RPSM",
     .data$repo == "none" ~ "not installed on this machine",
+    stringr::str_detect(.data$repo,"universe")~.data$repo,# for Runiverse pkgs
     TRUE ~ repo_details(.data$pkgname_clean)
   ), annotation = dplyr::case_when(stringr::str_detect(
     user_repo,
-    "/"
+    "/(?!.+r-universe.+)"
   ) ~ paste0("[", .data$repo, "::", user_repo, "]"), TRUE ~ user_repo))
   pck_descs <- dplyr::mutate(pck_descs, version = pkg_version(gsub("[\'\"]", "", .data$package_name)))
 
   # build annotations
   if (all(!grepl("p_load", pck_descs$call))) { # no pacman calls
-    pck_descs$annotated <- paste0(pck_descs$call, " # ", pck_descs$title, ", ", pck_descs$annotation, " v", pck_descs$version)
-
+    pck_descs <-  dplyr::mutate(pck_descs,annotated=dplyr::case_when(
+      stringr::str_detect(title,"not installed")~paste0(call, " # ", annotation, " vNA"),
+      TRUE~ paste0(call, " # ", title, " ", annotation, " v", version)
+    ))
     return(
-      align_annotations(stringi::stri_replace_all_fixed(
+      stringi::stri_replace_all_fixed(
         str = string_og, pattern = pck_descs$call,
         replacement = pck_descs$annotated, vectorize_all = FALSE
-      ))
+      )
     )
   }
 
   if (all(grepl("p_load", pck_descs$call))) { # only pacman calls
-    pacld <- pck_descs[stringr::str_detect(out_tb$call, ".+load\\("), ]
+    pacld <- pck_descs[which(stringr::str_detect(pck_descs$call, ".+load\\(")), ]
     pacld$pkgnamesep <- paste0(pacld$package_name, ", ")
     pacld <- dplyr::mutate(dplyr::group_by(pacld, call), pkgnamesep = ifelse(dplyr::row_number() == dplyr::n(), gsub(",", "", .data$pkgnamesep), .data$pkgnamesep))
-    pacld$annotatedpac <- paste0(pacld$pkgnamesep, "# ", pacld$title, pacld$annotation, " v", pacld$version)
+    pacld$annotatedpac <- paste0(pacld$pkgnamesep, "# ", pacld$title, " ", pacld$annotation, " v", pacld$version)
     pacld <- dplyr::summarize(dplyr::group_by(pacld, call), pkgs = paste(.data$annotatedpac, collapse = "\n"))
     pacld$ldcalls <- stringr::str_extract(pacld$call, ".+\\(")
     pacld <- dplyr::mutate(pacld, annotpac = paste(.data$ldcalls, .data$pkgs, ")", sep = "\n "))
     return(
-      align_annotations(stringi::stri_replace_all_fixed(
+      stringi::stri_replace_all_fixed(
         str = string_og, pattern = pacld$call,
         replacement = pacld$annotpac, vectorize_all = FALSE
-      ))
+      )
     )
   }
 
   if (any(grepl("p_load", pck_descs$call)) & any(grepl("libr|req", out_tb$call))) { # pacman and base calls
-    pacld <- pck_descs[stringr::str_detect(out_tb$call, ".+load\\("), ]
+    pacld <- pck_descs[which(stringr::str_detect(pck_descs$call, ".+load\\(")), ]
     pacld$pkgnamesep <- paste0(pacld$package_name, ", ")
     pacld <- dplyr::mutate(dplyr::group_by(pacld, call), pkgnamesep = ifelse(dplyr::row_number() == dplyr::n(), gsub(",", "", .data$pkgnamesep), .data$pkgnamesep))
     pacld$annotatedpac <- paste0(pacld$pkgnamesep, "# ", pacld$title, " ", pacld$annotation, " v", pacld$version)
@@ -89,8 +93,11 @@ annotate_repostitle <- function(string_og) {
       str = string_og, pattern = pacld$call,
       replacement = pacld$annotpac, vectorize_all = FALSE
     )
-    pck_descs <- pck_descs[!stringr::str_detect(out_tb$call, ".+load\\("), ]
-    pck_descs$annotated <- paste0(pck_descs$call, " # ", pck_descs$title, " ", pck_descs$annotation, " v", pck_descs$version)
+    pck_descs <- pck_descs[which(!stringr::str_detect(pck_descs$call, ".+load\\(")), ]
+    pck_descs <-  dplyr::mutate(pck_descs,annotated=dplyr::case_when(
+      stringr::str_detect(title,"not installed")~paste0(call, " #", " ", annotation, " vNA"),
+      TRUE~ paste0(call, " # ", title, " ", annotation, " v", version)
+    ))
 
     return(
       stringi::stri_replace_all_fixed(
