@@ -1,4 +1,4 @@
-#' Match Package Names
+#' Match package names
 #'
 #' @param string_og Text string (script) with package load calls.
 #'
@@ -36,9 +36,9 @@ match_pkg_names <- function(string_og) {
   colnames(pac_matches[[1]]) <- tb_names
   colnames(pacns_matches[[1]]) <- tb_names
   pac_tb <- tibble::as_tibble(pac_matches[[1]])
-  pac_tb_long <- tidyr::separate_rows(pac_tb, .data$package_name)
+  pac_tb_long <- tidyr::separate_rows(pac_tb, "package_name")
   pacns_tb <- tibble::as_tibble(pacns_matches[[1]])
-  pacns_tb_long <- tidyr::separate_rows(pacns_tb, .data$package_name)
+  pacns_tb_long <- tidyr::separate_rows(pacns_tb, "package_name")
   libreqpacout <- dplyr::bind_rows(lib_tb, req_tb, pac_tb_long, pacns_tb_long)
   dplyr::mutate(libreqpacout, pkgname_clean = stringr::str_remove_all(.data$package_name, "\"|'"))
 }
