@@ -1,4 +1,4 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
@@ -30,3 +30,9 @@ pluck(x, 1)
 map(x, pluck, 2)')
 annotate_fun_calls(testcode)
 
+## -----------------------------------------------------------------------------
+testcode <- c('library(tidyr) 
+summary(household)
+plot(fish_encounters)')
+annotate_pkg_datasets(testcode)
+
